@@ -2,7 +2,7 @@
  * Bignum.java
  *
  * Copyright (C) 2003-2007 Peter Graves
- * $Id: Bignum.java 14757 2015-04-11 07:44:42Z mevenson $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -85,14 +85,13 @@ public final class Bignum extends LispInteger
 
   @Override
   public Object javaInstance(Class c) {
-    String cn = c.getName();
-    if (cn.equals("java.lang.Byte") || cn.equals("byte"))
+    if (c == Byte.class || c == byte.class)
       return Byte.valueOf((byte)value.intValue());
-    if (cn.equals("java.lang.Short") || cn.equals("short"))
+    if (c == Short.class || c == short.class)
       return Short.valueOf((short)value.intValue());
-    if (cn.equals("java.lang.Integer") || cn.equals("int"))
+    if (c == Integer.class || c == int.class)
       return Integer.valueOf(value.intValue());
-    if (cn.equals("java.lang.Long") || cn.equals("long"))
+    if (c == Long.class || c == long.class)
       return Long.valueOf((long)value.longValue());
     return javaInstance();
   }
