@@ -1,7 +1,7 @@
 ;;; pathname-tests.lisp
 ;;;
 ;;; Copyright (C) 2005 Peter Graves
-;;; $Id: pathname-tests.lisp 14247 2012-11-16 00:27:44Z mevenson $
+;;; $Id$
 ;;;
 ;;; This program is free software; you can redistribute it and/or
 ;;; modify it under the terms of the GNU General Public License
@@ -1722,3 +1722,13 @@
        (pathname-name p) (pathname-type p) (pathname-version p) (pathname-directory p)))
   :wild :wild :wild (:absolute :wild))
       
+
+(deftest pathname.make-pathname.3
+    (signals-error
+     (make-pathname :directory '(:absolute ("a" "b")))
+     'file-error)
+  t)
+
+(deftest pathname.make-pathname.4
+    (directory-namestring (make-pathname :directory :unspecific))
+  "")
